/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef HAVE_uhub_COMMAND_H
#define HAVE_uhub_COMMAND_H

#include "uhub.h"


struct user;

struct adc_command
{
	fourcc_t cmd;
	sid_t source;
	sid_t target;
	char* cache;
	int length;
	int arguments;
	int arg_offset;
	int priority;
	int references;
	struct linked_list*  feature_cast_include;
	struct linked_list*  feature_cast_exclude;
};


extern struct adc_command* copy_command(struct adc_command* cmd);
extern struct adc_command* adc_parse_command(struct user* u, const char* string);
extern struct adc_command* adc_create_command(const char* string);
extern void command_free(struct adc_command* msg);
extern void command_incref(struct adc_command* msg);

extern int remove_named_argument(struct adc_command* cmd, const char prefix_[2]);
extern int has_named_argument(struct adc_command* cmd, const char prefix_[2]);
extern char* get_named_argument(struct adc_command* cmd, const char prefix_[2]);
extern char* get_argument(struct adc_command* cmd, int offset);

extern int replace_named_argument(struct adc_command* cmd, const char prefix_[2], const char* string); /* string needs to be escaped */
extern int add_argument(struct adc_command* cmd, const char* string); /* string needs to be escaped */
extern int add_named_argument(struct adc_command* cmd, const char prefix_[2], const char* string); /* string needs to be escaped */

extern int adc_inf_check_nick(struct user* u, struct adc_command* cmd);
extern int adc_inf_check_cid(struct user* u,  struct adc_command* cmd);

char* adc_cmd_unescape(const char* string);
char* adc_cmd_escape(const char* string);


#endif /* HAVE_uhub_COMMAND_H */
