/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef HAVE_uhub_HUB_H
#define HAVE_uhub_HUB_H

#include "uhub.h"

struct uhub_info
{
	int fd;
	struct uhub_config* config;
	struct linked_list* user_list;
	sid_t free_sid;
	struct acl_handle* acl;
	struct adc_command* command_info;
	struct adc_command* command_motd;
	struct adc_command* command_support;
	struct adc_command* command_banner;
	struct adc_command* command_error_hub_full;
	struct adc_command* command_error_hub_disabled;
	struct adc_command* command_error_nick_missing;
	struct adc_command* command_error_nick_invalid;
	struct adc_command* command_error_nick_taken;
	struct adc_command* command_error_cid_missing;
	struct adc_command* command_error_cid_invalid;
	struct adc_command* command_error_cid_taken;
	struct adc_command* command_error_pid_missing;
	struct adc_command* command_ban_perm;
	struct adc_command* command_ban_temp;
	struct adc_command* command_registered_only;
	struct adc_command* command_password_wrong;
};

extern void route_message(struct user* u, struct adc_command* msg);
extern void parse_hub_message(struct user* u, const char* message);

extern void on_support(struct user* u, struct adc_command* cmd);
extern void on_password(struct user* u, struct adc_command* cmd);
extern void on_kick(struct user* u, struct adc_command* cmd);
extern void on_info(struct user* u, struct adc_command* cmd);

extern void on_login_success(struct user* u, int authenticated);
extern void on_login_failure(struct user* u, struct adc_command* cmd, const char* message);

extern void send_support(struct user* u);
extern void send_sid(struct user* u);
extern void send_hubinfo(struct user* u);
extern void send_handshake(struct user* u);

extern int handle_client_network(struct net_event_listener* listener);
extern int handle_server_accept(struct net_event_listener* listener);

extern struct uhub_info* hub_start_service(struct uhub_config* config);
extern void hub_shutdown_service(struct uhub_info* hub);

extern void uhub_set_variables(struct uhub_info* hub, struct acl_handle* acl);
extern void uhub_free_variables(struct uhub_info* hub);


#endif /* HAVE_uhub_HUB_H */

