/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include "uhub.h"

static int verbosity = 4;

static const char* prefixes[] =
{
	"FATAL",
	"ERROR",
	"WARN",
	"INFO",
	"DEBUG",
	"TRACE",
	"DUMP",
	0
};

void uhub_set_log_verbosity(int verb)
{
	verbosity = verb;
}

void uhub_log(int log_verbosity, const char *format, ...)
{
	static char logmsg[1024];
	va_list args;
	
	if (log_verbosity < verbosity)
	{
		va_start(args, format);
		vsnprintf(logmsg, 1024, format, args);
		va_end(args);
		fprintf(stderr, "%s: %s\n", prefixes[log_verbosity], logmsg);
	}
}
