/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef HAVE_uhub_USER_H
#define HAVE_uhub_USER_H

#include "uhub.h"

struct uhub_info;

enum user_state
{
	state_none,
	state_protocol,
	state_identify,
	state_verify,
	state_normal,
	state_wait_disconnect,
};

enum user_credentials
{
	cred_none,
	cred_link,
	cred_user,
 	cred_user_registered,
	cred_operator,
	cred_admin,
};

enum user_features
{
	feature_base   = 0x00000001, /* Basic configuration */
	feature_auto   = 0x00000002, /* Automatic nat detection traversal */
	feature_bbs    = 0x00000004, /* Bulletin board system (not supported by this software) */
	feature_ucmd   = 0x00000008, /* User commands (not supported by this software) */
	feature_zlif   = 0x00000010, /* gzip stream compression (not supported by this software) */
};

struct user
{
	int                  sd;                    /* socket descriptor */
	int                  state;                 /* see enum user_state */
	int                  credentials;           /* see enum user_credentials */
	sid_t                sid;                   /* ADC session ID */
	char                 cid[MAX_CID_LEN+1];    /* ADC global client ID */
	char                 nick[MAX_NICK_LEN+1];  /* ADC nick name */
	time_t               tm_connected;          /* time when user connected */
	time_t               tm_last_read;          /* time the user last received something from the hub */
	time_t               tm_last_write;         /* time the user last sent something to the hub */
	int                  features;              /* see enum user_features */
	struct linked_list*  feature_cast;          /* Features supported by feature cast */
	struct adc_command*  info;                  /* ADC "INF" command */
	size_t               send_queue_offset;     /* Send queue byte offset */
	struct linked_list*  send_queue;            /* Send queue */
	int                  send_queue_size;       /* Size of send queue (in bytes, not messages) */
	char*                recv_buf;              /* Recv buffer */
	size_t               recv_buf_offset;       /* Recv buffer offset */
	struct uhub_info*    hub;                   /* The hub instance this user belong to */
};

extern int user_have_feature_cast_support(struct user* user, char feature[4]);

extern int user_manager_init(struct uhub_info* hub);
extern void user_manager_shutdown(struct uhub_info* hub);
extern void user_manager_process(struct uhub_info* hub);

extern struct user* create_user(struct uhub_info* hub, int sd);
extern void destroy_user(struct user* user);


extern struct user* get_user_by_sid(struct uhub_info* hub, sid_t sid);
extern struct user* get_user_by_cid(struct uhub_info* hub, const char* cid);
extern struct user* get_user_by_nick(struct uhub_info* hub, const char* nick);

extern void send_user_list(struct uhub_info* hub, struct user* user);
extern void send_quit_message(struct uhub_info* hub, struct user*);
extern void kick_user(struct user*);

extern void send_to_user(struct user*, struct adc_command* command);
extern void send_to_all(struct uhub_info* hub, struct adc_command* command);
extern void send_feature(struct uhub_info* hub, struct adc_command* command);
extern void send_queued_data(struct user* user);



#endif /* HAVE_uhub_USER_H */


